@@ -15,15 +15,6 @@ from huscy.projects.permissions import IsProjectCoordinator, ProjectPermission,
 logger = logging.getLogger('projects')
 
 
-def get_client_ip(request):
-    x_forwarded_for = request.META.get('HTTP_X_FORWARDED_FOR')
-    if x_forwarded_for:
-        ip = x_forwarded_for.split(',')[0]
-    else:
-        ip = request.META.get('REMOTE_ADDR')
-    return ip
-
-
 class MembershipViewSet(RevisionMixin, mixins.CreateModelMixin, mixins.DestroyModelMixin,
                         mixins.ListModelMixin, mixins.UpdateModelMixin, viewsets.GenericViewSet):
     serializer_class = serializers.MembershipSerializer
@@ -38,27 +29,27 @@ class MembershipViewSet(RevisionMixin, mixins.CreateModelMixin, mixins.DestroyMo
 
     def perform_create(self, serializer):
         membership = serializer.save(project=self.project)
-        set_comment('Created membership <ID-{membership.id}> for project <ID-{self.project.id}>')
+        set_comment(f'Created membership <ID-{membership.id}> for project <ID-{self.project.id}>')
 
-        logger.info('Membership created by user %s from IP %s for project "%s" and member %s',
-                    self.request.user.username, get_client_ip(self.request),
-                    membership.project.title, membership.user.get_full_name())
+        logger.info('Membership created by user %s for project "%s" and member %s',
+                    self.request.user.username, membership.project.title,
+                    membership.user.get_full_name())
 
     def perform_destroy(self, membership):
         services.delete_membership(membership)
-        set_comment('Deleted membership <ID-{membership.id}>')
+        set_comment(f'Deleted membership <ID-{membership.id}>')
 
-        logger.info('Membership deleted by user %s from IP %s for project "%s" and member %s',
-                    self.request.user.username, get_client_ip(self.request),
-                    membership.project.title, membership.user.get_full_name())
+        logger.info('Membership deleted by user %s for project "%s" and member %s',
+                    self.request.user.username, membership.project.title,
+                    membership.user.get_full_name())
 
     def perform_update(self, serializer):
         membership = serializer.save()
-        set_comment('Updated membership <ID-{membership.id}>')
+        set_comment(f'Updated membership <ID-{membership.id}>')
 
-        logger.info('Membership updated by user %s from IP %s for project "%s" and member %s',
-                    self.request.user.username, get_client_ip(self.request),
-                    membership.project.title, membership.user.get_full_name())
+        logger.info('Membership updated by user %s for project "%s" and member %s',
+                    self.request.user.username, membership.project.title,
+                    membership.user.get_full_name())
 
 
 class ProjectViewSet(RevisionMixin, mixins.CreateModelMixin, mixins.DestroyModelMixin,
@@ -82,22 +73,22 @@ class ProjectViewSet(RevisionMixin, mixins.CreateModelMixin, mixins.DestroyModel
         project = serializer.save()
         set_comment(f'Created project <ID-{project.id}>')
 
-        logger.info('Project created by user %s from IP %s with title "%s"',
-                    self.request.user.username, get_client_ip(self.request), project.title)
+        logger.info('Project created by user %s with title "%s"',
+                    self.request.user.username, project.title)
 
     def perform_destroy(self, project):
         services.delete_project(project)
         set_comment(f'Deleted project <ID-{project.id}>')
 
-        logger.info('Project deleted by user %s from IP %s with title "%s"',
-                    self.request.user.username, get_client_ip(self.request), project.title)
+        logger.info('Project deleted by user %s with title "%s"',
+                    self.request.user.username, project.title)
 
     def perform_update(self, serializer):
         project = serializer.save()
         set_comment(f'Updated project <ID-{project.id}>')
 
-        logger.info('Project updated by user %s from IP %s with title "%s"',
-                    self.request.user.username, get_client_ip(self.request), project.title)
+        logger.info('Project updated by user %s with title "%s"',
+                    self.request.user.username, project.title)
 
     @action(detail=True, methods=['PUT'],
             permission_classes=[IsAuthenticated, IsAdminUser | IsProjectCoordinator])
